#!/bin/bash
#
# Describer script for shaman daemon. Determining resource type (and possibly) state and name.
# Output format:
#       type(,state)
#       name
# Use RESOURCE & RESOURCE_PATH environment variables
# (c) 2013. Parallels IP Holdings GmbH. All rights reserved.
if [ -z "$RESOURCE" ]; then
        echo "RESOURCE environment variable undefined" 1>&2
        exit 1
fi

if [ -z "$RESOURCE_PATH" ]; then
        echo "RESOURCE_PATH environment variable undefined" 1>&2
        exit 1
fi

TYPE="ISCSI"
TARGET=${RESOURCE}
TARGET_BUNDLE=${RESOURCE_PATH}
if [ ! -d "${TARGET_BUNDLE}" ]; then
        echo "Directory '${TARGET_BUNDLE}' does not exist" 2>&1
        exit 3;
fi

# get target status (running or not)
if [ -f "${TARGET_BUNDLE}/control/.running" ]; then
        STATE="running"
else
        STATE="stopped"
fi

echo "<descr type=\"${TYPE}\">"
        echo "<id width=\"20\">${TARGET}</id>"
        echo "<state width=\"10\">${STATE}</state>"
echo "</descr>"

exit 0

