#!/bin/bash
#
# relocation script for shaman daemon for Pstorage ISCSI target
# Use RESOURCE_ID & RESOURCE_PATH environment variables
#
# (c) 2012. Parallels IP Holdings GmbH. All rights reserved.
if [ -z "$RESOURCE_ID" ]; then
        echo "RESOURCE_ID environment variable undefined" 1>&2
        exit 1
fi

if [ -z "$RESOURCE_PATH" ]; then
        echo "RESOURCE_PATH environment variable undefined" 1>&2
        exit 1
fi

if [ ! -d "${RESOURCE_PATH}" ]; then
        echo "Directory '${RESOURCE_PATH}' does not exist" 1>&2
        exit 2;
fi

PSTORAGE_ISCSI_LIB=/usr/libexec/pstorage-iscsi/iscsi_functions
if [ ! -x $PSTORAGE_ISCSI_LIB ] ; then
	echo "Unable find executable $PSTORAGE_ISCSI_LIB" 1>&2
	exit 2
fi
source $PSTORAGE_ISCSI_LIB

[ -f $ISCSI_ETC/config ] && source $ISCSI_ETC/config
if [ -z "$ISCSI_ROOT" ] ; then
	echo "ISCSI_ROOT environment variable undefined, please check $ISCSI_ETC/config file" 1>&2
	exit 3
fi

if [ ! -d "$ISCSI_ROOT" ]; then
	echo "Directory '$ISCSI_ROOT' does not exist" 1>&2
	exit 4
fi

TARGET=${RESOURCE_ID}
ISCSI_ROOT=`dirname ${RESOURCE_PATH}`
STATUS="stopped"

if [ -e "${RESOURCE_PATH}/control/.running" ]; then
        STATUS="running"
fi

pcs_iscsi_register_target `basename "${RESOURCE_PATH}" ` 1>&2
if [ $? -ne 0 ] ; then
	echo "Unable register ISCSI target ${TARGET}"
	exit 5
fi

if [ "X$STATUS" == "Xrunning" ]; then
	pcs_iscsi_up_target ${TARGET} 1>&2
	[ $? -ne 0 ] && exit 5
fi

exit 0

